summaryrefslogtreecommitdiffstats
path: root/src/usr/diag/prdf/common/plat/prdfPlatServices_common.H
diff options
context:
space:
mode:
authorZane Shelley <zshelle@us.ibm.com>2018-06-05 13:19:27 -0500
committerZane C. Shelley <zshelle@us.ibm.com>2018-06-08 22:46:06 -0400
commitf54c91bffdc2d9c41fb22e0f7a97f6db8e1d636e (patch)
treed028e7d8331b90e3ca93322aa9085639f8679ab0 /src/usr/diag/prdf/common/plat/prdfPlatServices_common.H
parentbcfc61239031341766108f5a8c32a8284f945202 (diff)
downloadtalos-hostboot-f54c91bffdc2d9c41fb22e0f7a97f6db8e1d636e.tar.gz
talos-hostboot-f54c91bffdc2d9c41fb22e0f7a97f6db8e1d636e.zip
PRD: removed erroneous trace in getMemBufRawCardType()
Change-Id: Ie7cc0db26fb33f5b70f5c51229c99a809318d663 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/59979 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Reviewed-by: Matt Derksen <mderkse1@us.ibm.com> Reviewed-by: Benjamin J. Weisenbeck <bweisenb@us.ibm.com> Reviewed-by: Caleb N. Palmer <cnpalmer@us.ibm.com> Reviewed-by: Brian J. Stegmiller <bjs@us.ibm.com> Reviewed-by: Zane C. Shelley <zshelle@us.ibm.com> Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/60143 Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP HW <op-hw-jenkins+hostboot@us.ibm.com>
Diffstat (limited to 'src/usr/diag/prdf/common/plat/prdfPlatServices_common.H')
-rwxr-xr-xsrc/usr/diag/prdf/common/plat/prdfPlatServices_common.H11
1 files changed, 5 insertions, 6 deletions
diff --git a/src/usr/diag/prdf/common/plat/prdfPlatServices_common.H b/src/usr/diag/prdf/common/plat/prdfPlatServices_common.H
index 367e35f2a..de41a416a 100755
--- a/src/usr/diag/prdf/common/plat/prdfPlatServices_common.H
+++ b/src/usr/diag/prdf/common/plat/prdfPlatServices_common.H
@@ -259,13 +259,12 @@ int32_t getDimmSpareConfig( TARGETING::TargetHandle_t i_mba, MemRank i_rank,
/**
* @brief Returns the raw card type of a buffered DIMM.
* @param i_mbaTarget An MBA target. This MBA must be on a buffered DIMM.
* @param o_wiringType The DIMM's raw card type. Will return WIRING_INVALID if
* the raw card type currently is not supported.
* @return Non-SUCCESS if an internal function fails, SUCCESS otherwise.
*/
-int32_t getMemBufRawCardType( TARGETING::TargetHandle_t i_mbaTarget,
- CEN_SYMBOL::WiringType & o_wiringType );
+template<TARGETING::TYPE>
+CEN_SYMBOL::WiringType getMemBufRawCardType( TARGETING::TargetHandle_t i_trgt );
/**
* @brief get DIMM DQ map from FAPI routines
OpenPOWER on IntegriCloud
@@ -259,13 +259,12 @@ int32_t getDimmSpareConfig( TARGETING::TargetHandle_t i_mba, MemRank i_rank,
/**
* @brief Returns the raw card type of a buffered DIMM.
- * @param i_mbaTarget An MBA target. This MBA must be on a buffered DIMM.
- * @param o_wiringType The DIMM's raw card type. Will return WIRING_INVALID if
- * the raw card type currently is not supported.
- * @return Non-SUCCESS if an internal function fails, SUCCESS otherwise.
+ * @param i_trgt An MBA target.
+ * @return WIRING_INVALID if an internal function fails. Otherwise, the DIMM's
+ * raw card type.
*/